--[[
AdiFocusBar - Smart focus bar for hunters.
Copyright 2010-2013 Adirelle (adirelle@gmail.com)
All rights reserved.
--]]

if select(2, UnitClass("player")) ~= "HUNTER" then return end
local addonName, ns = ...
local addon, Debug = ns.addon, ns.Debug

------------------------------------------------------------------------------
-- Configuration
------------------------------------------------------------------------------

local options
local function GetOptions()
	if not options then
		options = {
			name = addonName,
			type = 'group',
			set = function(info, value)
				addon.db.profile[info[#info]] = value
			end,
			get = function(info)
				return addon.db.profile[info[#info]]
			end,
			args = {
				enabled = {
					name = 'Active features',
					order = 10,
					type = 'group',
					inline = true,
					get = function(info)
						local widget = addon[info[#info]]
						return widget:IsEnabled()
					end,
					set = function(info, value)
						local widget = addon[info[#info]]
						if value then
							widget:Enable()
						else
							widget:Disable()
						end
					end,
					args = {
						Bar = {
							name = 'Focus bar',
							type = 'toggle',
						},
						Forecast = {
							name = 'Spell forecast',
							type = 'toggle',
						},
					}
				},
				layout = {
					name = 'Layout',
					order = 20,
					type = 'group',
					inline = true,
					args = {
						locked = {
							name = function()
								return addon:AreMovablesLocked() and "Unlock" or "Lock"
							end,
							order = 10,
							type = 'execute',
							func = function()
								if addon:AreMovablesLocked() then
									addon:UnlockMovables()
								else
									addon:LockMovables()
								end
							end
						},
						reset = {
							name = 'Reset',
							order = 20,
							type = 'execute',
							func = function() addon:ResetMovableLayout() end
						}
					}
				},
			},
		}
	end
	return options
end

------------------------------------------------------------------------------
-- Setup
------------------------------------------------------------------------------

function addon:SetupConfig()
	-- Create the config panel
	LibStub("AceConfig-3.0"):RegisterOptionsTable(addonName, GetOptions)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions(addonName, addonName)

	-- Add a macro command to open it
	SlashCmdList["ADIFOCUSBAR"] = function()
		InterfaceOptionsFrame_OpenToCategory(addonName)
	end
	SLASH_ADIFOCUSBAR1 = "/adifocusbar"
	SLASH_ADIFOCUSBAR2 = "/afb"
end
